
## Introduction

`pyriodic-aflow` is an adapter that makes the [crystal
prototypes](http://aflowlib.org/CrystalDatabase/) found in the [AFLOW
project](http://aflowlib.org/) available using the API of the
[pyriodic](https://github.com/klarh/pyriodic) python library.

This project is not affiliated with AFLOW and merely provides a
streamlined way to access the data using a python interface.

## Installation

Install `pyriodic-aflow` from source:

```
pip install git+https://github.com/klarh/pyriodic-aflow
```

## Citation

The AFLOW developers request that you cite the following papers when
using data from their database:

* M. J. Mehl, D. Hicks, C. Toher, O. Levy, R. M. Hanson, G. L. W. Hart, and S. Curtarolo, The AFLOW Library of Crystallographic Prototypes: Part 1, Comp. Mat. Sci. 136, S1-S828 (2017). [(doi=10.1016/j.commatsci.2017.01.017)](http://dx.doi.org/10.1016/j.commatsci.2017.01.017)
* D. Hicks, M. J. Mehl, E. Gossett, C. Toher, O. Levy, R. M. Hanson, G. L. W. Hart, and S. Curtarolo, The AFLOW Library of Crystallographic Prototypes: Part 2, Comp. Mat. Sci. 161, S1-S1011 (2019). [(doi=10.1016/j.commatsci.2018.10.043)](http://dx.doi.org/10.1016/j.commatsci.2018.10.043)